parse_strict

Function parse_strict 

pub fn parse_strict<ByteStream: IntoIterator<Item = u8>>(
    byte_stream: ByteStream,
) -> impl Iterator<Item = Result<ReportItem, HidError>>
Parse a byte stream into a report item iterator in strict mode.

Items that cannot be recognized will be treated as HidError::ReservedItem. Also, this is the only error that may be reported.