LogicalMaximum

Struct LogicalMaximum 

pub struct LogicalMaximum(/* private fields */);
Extent value in logical units. This is the maximum value that a variable or array item will report.

For example, a mouse reporting x position values from 0 to 128 would have a Logical Minimum of 0 and a Logical Maximum of 128.

Implementations

Source

impl LogicalMaximum

pub const PREFIX: u8 = 36u8

Prefix consists of tag(bit 7-4), type(bit 3-2) and size(bit 1-0). The “size” part is set to 00 in this constant value.

pub fn new(raw: &[u8]) -> Result<Self, HidError>

Create an item with prefix check.

pub unsafe fn new_unchecked(raw: &[u8]) -> Self

Create an item WITHOUT prefix check.

Safety

Must ensure that the prefix part is correct.

pub fn prefix(&self) -> u8

Get prefix part of the item. Equivalent to item.as_ref()[0].

pub fn data(&self) -> &[u8]

Get data part of the item. Equivalent to &item.as_ref()[1..].

pub fn new_with(data: &[u8]) -> Result<Self, HidError>

Create an item with specific data.

NOTE: data size must be: 0, 1, 2 or 4.

pub fn set_data(&mut self, data: &[u8]) -> Result<&mut Self, HidError>

Set data part of the item.

NOTE: data size must be: 0, 1, 2 or 4.

pub fn data_mut(&mut self) -> &mut [u8]

Get mutable data part of the item.