pub struct ReportSize(/* private fields */);Expand description
Unsigned integer specifying the size of the report fields in bits.
This allows the parser to build an item map for the report handler to use.
Implementations
Sourceimpl ReportSize
impl ReportSize
Sourcepub const PREFIX: u8 = 116u8
pub const PREFIX: u8 = 116u8
Prefix consists of tag(bit 7-4), type(bit 3-2) and size(bit 1-0).
The “size” part is set to 00 in this constant value.
Sourcepub unsafe fn new_unchecked(raw: &[u8]) -> Self
pub unsafe fn new_unchecked(raw: &[u8]) -> Self
Sourcepub fn new_with(data: &[u8]) -> Result<Self, HidError>
pub fn new_with(data: &[u8]) -> Result<Self, HidError>
Create an item with specific data.
NOTE: data size must be: 0, 1, 2 or 4.