pub struct UsageMinimum { /* private fields */ }Expand description
Defines the starting usage associated with an array or bitmap.
Data (Little Endian)
Depends on the value of UsagePage. See HID Usage Tables FOR Universal Serial Bus.
Implementations
Sourceimpl UsageMinimum
impl UsageMinimum
Sourcepub const PREFIX: u8 = 24u8
pub const PREFIX: u8 = 24u8
Prefix consists of tag(bit 7-4), type(bit 3-2) and size(bit 1-0).
The “size” part is set to 00 in this constant value.
Sourcepub unsafe fn new_unchecked(raw: &[u8]) -> Self
pub unsafe fn new_unchecked(raw: &[u8]) -> Self
Sourcepub fn set_usage_page(&mut self, usage_page: UsagePage)
pub fn set_usage_page(&mut self, usage_page: UsagePage)
If you want more detailed content printed when formatting, you need to set the related usage page.
Equality
Equality between two UsageMinimum items ignores usage page.
Sourcepub fn usage_page(&self) -> Option<&UsagePage>
pub fn usage_page(&self) -> Option<&UsagePage>
Get usage page.
Sourcepub fn new_with(data: &[u8]) -> Result<Self, HidError>
pub fn new_with(data: &[u8]) -> Result<Self, HidError>
Create an item with specific data.
NOTE: data size must be: 0, 1, 2 or 4.