pub struct LogicalMaximum(/* private fields */);Expand description
Extent value in logical units. This is the maximum value that a variable or array item will report.
For example, a mouse reporting x position values from 0 to 128 would have a Logical Minimum of 0 and a Logical Maximum of 128.
Implementations
Sourceimpl LogicalMaximum
impl LogicalMaximum
Sourcepub const PREFIX: u8 = 36u8
pub const PREFIX: u8 = 36u8
Prefix consists of tag(bit 7-4), type(bit 3-2) and size(bit 1-0).
The “size” part is set to 00 in this constant value.
Sourcepub unsafe fn new_unchecked(raw: &[u8]) -> Self
pub unsafe fn new_unchecked(raw: &[u8]) -> Self
Sourcepub fn new_with(data: &[u8]) -> Result<Self, HidError>
pub fn new_with(data: &[u8]) -> Result<Self, HidError>
Create an item with specific data.
NOTE: data size must be: 0, 1, 2 or 4.